import json

from django import template
from django.apps import apps


register = template.Library()
quilljs_app = apps.get_app_config('quilljs')


@register.filter()
def quilljs_conf(name):
    """Get a value from the configuration app."""
    return getattr(quilljs_app, name)
quilljs_conf.is_safe = True


@register.filter()
def quilljs_conf_json(name):
    """Get a value from the configuration app as JSON."""
    return json.dumps(getattr(quilljs_app, name))
quilljs_conf_json.is_safe = True


@register.simple_tag(takes_context=True)
def render_toolbar(context, config):
    """Render the toolbar for the given config."""
    quilljs_config = getattr(quilljs_app, config)
    t = template.loader.get_template(quilljs_config['toolbar_template'])
    return t.render(context.flatten())


@register.simple_tag(takes_context=True)
def render_editor(context, config):
    """Render the editor for the given config."""
    quilljs_config = getattr(quilljs_app, config)
    t = template.loader.get_template(quilljs_config['editor_template'])
    return t.render(context.flatten())



def save_file(data, filename, is_raw, storage):
    BUFFER_SIZE = 5 * 1024 * 1024  # 5mb
    saved_filename = storage.get_available_name(filename)
    with storage.open(saved_filename, "wb") as dest:
        if is_raw:
            chunk = data.read(BUFFER_SIZE)
            while chunk:
                dest.write(chunk)
                chunk = data.read(BUFFER_SIZE)
        else:
            for c in data.chunks():
                dest.write(c)
    return storage.url(saved_filename)



from django import forms
from django.apps import apps
from django.forms.utils import flatatt
from django.template.loader import render_to_string
from django.templatetags.static import static
from django.utils.safestring import mark_safe


class QuillEditorWidget(forms.Textarea):

    """Widget used to render a QuillJS WYSIWYG."""

    class Media:
        css = {
            'all': (
                static('quilljs/css/quilljs.snow.min.css'),
                static('quilljs/css/quilljs.core.css'),
                static('quilljs/css/quilljs.css'),
            )
        }

        js = (
            static('quilljs/js/vendor/SimpleAjaxUploader-1a6f62289d.min.js'),
            static('quilljs/js/build/quilljs-django.min.js'),
        )

    def __init__(self, config='default', *args, **kwargs):
        """Create a new Quill WYSIWYG Widget.

        :param str config: The QuillJS config to use (from :py:class:`quilljs.apps.QuilljsConfig`)

        """
        self.config = config
        super(QuillEditorWidget, self).__init__(*args, **kwargs)

    def render(self, name, value, attrs=None, renderer=None):
        """Render the Quill WYSIWYG."""
        if value is None:
            value = ''
        final_attrs = self.build_attrs(attrs, {'name': name})
        quilljs_app = apps.get_app_config('quilljs')
        quilljs_config = getattr(quilljs_app, self.config)

        return mark_safe(render_to_string(quilljs_config['template'], {
            'final_attrs': flatatt(final_attrs),
            'value': value,
            'id': final_attrs['id'],
            'config': self.config,
        }))



import os

from codecs import open
from setuptools import setup

import quilljs

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-quilljs',
    version=quilljs.__version__,
    author='Mukesh Yadav',
    author_email='mak.gnu@gmail.com',
    description='Easily use Quill.js in your django admin.',
    long_description=long_description,
    packages=['quilljs'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        "Topic :: Internet :: WWW/HTTP :: Browsers",
        "Topic :: Internet :: WWW/HTTP :: Site Management",
        "Topic :: Office/Business :: Office Suites",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: User Interfaces",
        "Topic :: Text Editors :: Word Processors",
        "Topic :: Text Processing :: Fonts",
        "Topic :: Text Processing :: Markup :: HTML"
    ]
)
